@@ -391,15 +391,15 @@ PyMethodDef PyCOMPSDict_methods[] = {
      {"get", (PyCFunction)PyCOMPSDict_get_, METH_O, PyCOMPSDict_get__doc__},
      {"has_key", (PyCFunction)PyCOMPSDict_has_key, METH_O,
        PyCOMPSDict_has_key__doc__},
-     {"items", (PyCFunction)PyCOMPSDict_getiteritems, METH_NOARGS,
+     {"items", _PyCFunction_CAST(PyCOMPSDict_getiteritems), METH_NOARGS,
      "return iterator returning (key, value) tuple"},
-     {"values", (PyCFunction)PyCOMPSDict_getitervalues, METH_NOARGS,
+     {"values", _PyCFunction_CAST(PyCOMPSDict_getitervalues), METH_NOARGS,
      "return iterator returning item's value"},
-     {"keys", (PyCFunction)PyCOMPSDict_getiter, METH_NOARGS,
+     {"keys", _PyCFunction_CAST(PyCOMPSDict_getiter), METH_NOARGS,
      "return iterator returning item's key"},
-     {"clear", (PyCFunction)PyCOMPSDict_clear, METH_NOARGS,
+     {"clear", _PyCFunction_CAST(PyCOMPSDict_clear), METH_NOARGS,
      "clear the dict"},
-     {"copy", (PyCFunction)PyCOMPSDict_copy, METH_NOARGS,
+     {"copy", _PyCFunction_CAST(PyCOMPSDict_copy), METH_NOARGS,
      "return shallow copy of dict"},
      {"update", (PyCFunction)PyCOMPSDict_update, METH_O,
       PyCOMPSDict_update__doc__},
